"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var remap_1 = require("./remap");
describe('remap', function () {
    it('remaps shallow objects', function () {
        var mapping = { a: 'b' };
        var object = { b: 1 };
        var expected = { a: 1 };
        var actual = remap_1.remap(mapping, object);
        chai_1.expect(actual).to.eql(expected);
    });
    it('remaps from deep objects', function () {
        var mapping = { a: 'b.c' };
        var object = { b: { c: 1 } };
        var expected = { a: 1 };
        var actual = remap_1.remap(mapping, object);
        chai_1.expect(actual).to.eql(expected);
    });
    it('remaps to deep objects', function () {
        var mapping = { a: { b: 'c' } };
        var object = { c: 1 };
        var expected = { a: { b: 1 } };
        var actual = remap_1.remap(mapping, object);
        chai_1.expect(actual).to.eql(expected);
    });
    it('allows function mappings', function () {
        var mapping = { a: function (obj) { return obj.b; } };
        var object = { b: 1 };
        var expected = { a: 1 };
        var actual = remap_1.remap(mapping, object);
        chai_1.expect(actual).to.eql(expected);
    });
    it('uses same path if mapping is empty string', function () {
        var mapping = { a: '' };
        var object = { a: 1, b: 2 };
        var expected = { a: 1 };
        var actual = remap_1.remap(mapping, object);
        chai_1.expect(actual).to.eql(expected);
    });
});
//# sourceMappingURL=remap.spec.js.map