"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path_1 = require("./path");
describe('path', function () {
    it('selects a first-level prop', function () {
        var obj = { a: 1 };
        chai_1.expect(path_1.path(['a'], obj)).to.equal(1);
    });
    it('selects a second-level prop', function () {
        var obj = { a: { b: 1 } };
        chai_1.expect(path_1.path(['a', 'b'], obj)).to.equal(1);
    });
    it('selects a third-level prop', function () {
        var obj = { a: { b: { c: 1 } } };
        chai_1.expect(path_1.path(['a', 'b', 'c'], obj)).to.equal(1);
    });
    it('selects a falsy value', function () {
        var obj = {
            a: false,
            b: 0,
            c: '',
            d: undefined,
        };
        chai_1.expect(path_1.path(['a'], obj)).to.equal(false);
        chai_1.expect(path_1.path(['b'], obj)).to.equal(0);
        chai_1.expect(path_1.path(['c'], obj)).to.equal('');
        chai_1.expect(path_1.path(['d'], obj)).to.equal(undefined);
    });
    it('returns undefined for non-existent props', function () {
        var obj = { a: 1 };
        chai_1.expect(path_1.path(['b'], obj)).to.equal(undefined);
    });
    it('selects over arrays', function () {
        var arr = [1];
        chai_1.expect(path_1.path([0], arr)).to.equal(1);
        chai_1.expect(path_1.path(['0'], arr)).to.equal(1);
    });
});
//# sourceMappingURL=path.spec.js.map